@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x8fdac94
+# __coconut_hash__ = 0x46926f42
 
-# Compiled with Coconut version 1.5.0-post_dev12 [Fish License]
+# Compiled with Coconut version 1.5.0-post_dev49 [Fish License]
 
 """
 The mixture backend. Lets you specify a distribution over different possible algorithms.
@@ -18,7 +18,7 @@ if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cach
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_path)
 from __coconut__ import *
-from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
+from __coconut__ import _coconut_call_set_names, _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
 if _coconut_sys.version_info >= (3,):
     _coconut_sys.path.pop(0)
 
@@ -54,6 +54,7 @@ class MixtureBackend(Backend):
         self.backend_store = {}
         self.tell_examples(examples)
 
+    @override
     def tell_examples(self, examples):
         """Special method that allows fast updating of the backend with new examples."""
 # randomly select algorithm
@@ -69,6 +70,7 @@ class MixtureBackend(Backend):
         self.current_backend = init_backend(self.selected_backend, examples, self.params, attempt_to_update_backend=self.backend_store.get(self.selected_alg), **options)
         self.backend_store[self.selected_alg] = self.current_backend
 
+    @override
     def param(self, name, func, *args, **kwargs):
         """Defer parameter selection to the selected backend."""
         return self.current_backend.param(name, func, *args, **kwargs)
@@ -76,4 +78,8 @@ class MixtureBackend(Backend):
 
 # Registered names:
 
+_coconut_call_set_names(MixtureBackend)
+EPS = 0.1
+
 MixtureBackend.register()
+MixtureBackend.register_alg("epsilon_greedy", distribution=(("random", EPS), ("serving", 1 - EPS),))
