@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x82a5a2e1
+# __coconut_hash__ = 0x9f5d37c8
 
-# Compiled with Coconut version 1.5.0-post_dev12 [Fish License]
+# Compiled with Coconut version 1.5.0-post_dev49 [Fish License]
 
 """
 The main BBopt interface.
@@ -18,7 +18,7 @@ if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cach
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_path)
 from __coconut__ import *
-from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
+from __coconut__ import _coconut_call_set_names, _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
 if _coconut_sys.version_info >= (3,):
     _coconut_sys.path.pop(0)
 
@@ -57,6 +57,7 @@ from bbopt.util import running_best
 from bbopt.util import plot
 from bbopt.util import open_with_lock
 from bbopt.util import printerr
+from bbopt.util import convert_match_errors
 from bbopt.backends.serving import ServingBackend
 
 
@@ -73,36 +74,34 @@ def array_param(func, name, shape, kwargs):
     return arr
 
 
-DEFAULT_ALG_SENTINEL = object()
-
-
 class BlackBoxOptimizer(_coconut.object):
     """Main bbopt optimizer object. See https://github.com/evhub/bbopt for documentation."""
+    DEFAULT_ALG_SENTINEL = object()
     backend = None
     _new_params = None
     _current_example = None
 
+    _coconut_decorator_0 = _coconut.functools.partial(convert_match_errors, "BlackBoxOptimizer.__init__")
+    @_coconut_decorator_0
     @_coconut_mark_as_match
-    def __init__(*_coconut_match_to_args, **_coconut_match_to_kwargs):
+    def __init__(*_coconut_match_args, **_coconut_match_kwargs):
         """Construct a new BlackBoxOptimizer. It is recommended to pass file=__file__."""
-        _coconut_match_check = False
+        _coconut_match_check_0 = False
         _coconut_FunctionMatchError = _coconut_get_function_match_error()
-        if (_coconut.len(_coconut_match_to_args) <= 2) and (_coconut.sum((_coconut.len(_coconut_match_to_args) > 0, "self" in _coconut_match_to_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_to_args) > 1, "file" in _coconut_match_to_kwargs)) == 1):
-            _coconut_match_temp_0 = _coconut_match_to_args[0] if _coconut.len(_coconut_match_to_args) > 0 else _coconut_match_to_kwargs.pop("self")
-            _coconut_match_temp_1 = _coconut_match_to_args[1] if _coconut.len(_coconut_match_to_args) > 1 else _coconut_match_to_kwargs.pop("file")
-            _coconut_match_temp_2 = _coconut_match_to_kwargs.pop("tag") if "tag" in _coconut_match_to_kwargs else None
-            _coconut_match_temp_3 = _coconut_match_to_kwargs.pop("protocol") if "protocol" in _coconut_match_to_kwargs else None
-            if not _coconut_match_to_kwargs:
+        if (_coconut.len(_coconut_match_args) <= 2) and (_coconut.sum((_coconut.len(_coconut_match_args) > 0, "self" in _coconut_match_kwargs)) == 1) and (_coconut.sum((_coconut.len(_coconut_match_args) > 1, "file" in _coconut_match_kwargs)) == 1):
+            _coconut_match_temp_0 = _coconut_match_args[0] if _coconut.len(_coconut_match_args) > 0 else _coconut_match_kwargs.pop("self")
+            _coconut_match_temp_1 = _coconut_match_args[1] if _coconut.len(_coconut_match_args) > 1 else _coconut_match_kwargs.pop("file")
+            _coconut_match_temp_2 = _coconut_match_kwargs.pop("tag") if "tag" in _coconut_match_kwargs else None
+            _coconut_match_temp_3 = _coconut_match_kwargs.pop("protocol") if "protocol" in _coconut_match_kwargs else None
+            if (_coconut.isinstance(_coconut_match_temp_1, Str)) and (not _coconut_match_kwargs):
                 self = _coconut_match_temp_0
                 file = _coconut_match_temp_1
                 tag = _coconut_match_temp_2
                 protocol = _coconut_match_temp_3
-                _coconut_match_check = True
-        if not _coconut_match_check:
-            raise _coconut_FunctionMatchError('match def __init__(self, file, *, tag=None, protocol=None):', _coconut_match_to_args)
+                _coconut_match_check_0 = True
+        if not _coconut_match_check_0:
+            raise _coconut_FunctionMatchError('match def __init__(self, file is Str, *, tag=None, protocol=None):', _coconut_match_args)
 
-        if not isinstance(file, Str):
-            raise TypeError("file must be a string")
         self._file = norm_path(file)
         self._tag = tag
 
@@ -167,17 +166,17 @@ class BlackBoxOptimizer(_coconut.object):
         """Load data from the given file."""
         contents = df.read()
         if contents:
-            _coconut_match_to = self._loads(contents)
-            _coconut_match_check = False
-            if (_coconut.isinstance(_coconut_match_to, _coconut.abc.Mapping)) and (_coconut.len(_coconut_match_to) == 2):
-                _coconut_match_temp_0 = _coconut_match_to.get("params", _coconut_sentinel)
-                _coconut_match_temp_1 = _coconut_match_to.get("examples", _coconut_sentinel)
+            _coconut_match_to_0 = self._loads(contents)
+            _coconut_match_check_1 = False
+            if (_coconut.isinstance(_coconut_match_to_0, _coconut.abc.Mapping)) and (_coconut.len(_coconut_match_to_0) == 2):
+                _coconut_match_temp_0 = _coconut_match_to_0.get("params", _coconut_sentinel)
+                _coconut_match_temp_1 = _coconut_match_to_0.get("examples", _coconut_sentinel)
                 if (_coconut_match_temp_0 is not _coconut_sentinel) and (_coconut_match_temp_1 is not _coconut_sentinel):
                     params = _coconut_match_temp_0
                     examples = _coconut_match_temp_1
-                    _coconut_match_check = True
-            if not _coconut_match_check:
-                raise _coconut_MatchError('{"params": params, "examples": examples} = self._loads(contents)', _coconut_match_to)
+                    _coconut_match_check_1 = True
+            if not _coconut_match_check_1:
+                raise _coconut_MatchError('{"params": params, "examples": examples} = self._loads(contents)', _coconut_match_to_0)
 
             self._old_params = params
             self._add_examples(examples)
@@ -206,7 +205,7 @@ class BlackBoxOptimizer(_coconut.object):
 
     @property
     def _metric(self):
-        """Whether using a gain, a loss, or no examples."""
+        """Whether using a gain or a loss."""
         assert self._examples, "cannot determine metric from empty examples"
         return "gain" if "gain" in self._examples[0] else "loss"
 
@@ -241,16 +240,16 @@ class BlackBoxOptimizer(_coconut.object):
         args = param_processor.standardize_args(func, args)
         kwargs = param_processor.standardize_kwargs(kwargs)
 
-        _coconut_match_to = self._old_params
-        _coconut_match_check = False
-        if _coconut.isinstance(_coconut_match_to, _coconut.abc.Mapping):
-            _coconut_match_temp_0 = _coconut_match_to.get(name, _coconut_sentinel)
+        _coconut_match_to_1 = self._old_params
+        _coconut_match_check_2 = False
+        if _coconut.isinstance(_coconut_match_to_1, _coconut.abc.Mapping):
+            _coconut_match_temp_0 = _coconut_match_to_1.get(name, _coconut_sentinel)
             if (_coconut_match_temp_0 is not _coconut_sentinel) and (_coconut.isinstance(_coconut_match_temp_0, _coconut.abc.Sequence)) and (_coconut.len(_coconut_match_temp_0) == 3):
                 old_func = _coconut_match_temp_0[0]
                 old_args = _coconut_match_temp_0[1]
                 old_kwargs = _coconut_match_temp_0[2]
-                _coconut_match_check = True
-        if _coconut_match_check:
+                _coconut_match_check_2 = True
+        if _coconut_match_check_2:
             if (func, args) != (old_func, old_args):
                 printerr("BBopt Warning: detected change in parameter {_coconut_format_0} ({_coconut_format_1} != {_coconut_format_2}) (you may need to delete your old BBopt data)".format(_coconut_format_0=(name), _coconut_format_1=((func, args)), _coconut_format_2=((old_func, old_args))))
 
@@ -280,7 +279,7 @@ class BlackBoxOptimizer(_coconut.object):
     def run(self, alg=DEFAULT_ALG_SENTINEL):
         """Optimize parameters using the given algorithm
         (use .algs to get the list of valid algorithms)."""
-        if alg is DEFAULT_ALG_SENTINEL:
+        if alg is self.DEFAULT_ALG_SENTINEL:
             alg = constants.default_alg
         backend, options = alg_registry[alg]
         self.run_backend(backend, **options)
@@ -343,10 +342,12 @@ class BlackBoxOptimizer(_coconut.object):
             raise ValueError("get_current_run calls must come after run")
         return self._current_example
 
-    def get_optimal_run(self):
-        """Return a dictionary containing the optimal parameters and reward computed so far."""
+    def get_best_run(self):
+        """Return a dictionary containing the best parameters and reward computed so far."""
         return best_example(self._examples)
 
+    get_optimal_run = get_best_run
+
 # Plotting functions:
 
     def plot_convergence(self, ax=None, yscale=None):
@@ -372,7 +373,7 @@ class BlackBoxOptimizer(_coconut.object):
 
     def partial_dependence(self, i_name, j_name=None, *args, **kwargs):
         """Calls skopt.plots.partial_dependence where i_name and j_name are parameter names."""
-        def _coconut_mock_func(self, i_name, j_name=None, *args, **kwargs): return self, i_name, j_name, args, kwargs
+        def _coconut_mock_6(self, i_name, j_name=None, *args, **kwargs): return self, i_name, j_name, args, kwargs
         while True:
             from skopt.plots import partial_dependence
             if not self._examples:
@@ -385,18 +386,18 @@ class BlackBoxOptimizer(_coconut.object):
             j = None if j_name is None else sorted_names.index(j_name)
 
             try:
-                _coconut_is_recursive = partial_dependence is _coconut_recursive_func_25
+                _coconut_tre_check_0 = partial_dependence is _coconut_recursive_func_24
             except _coconut.NameError:
-                _coconut_is_recursive = False
-            if _coconut_is_recursive:
-                self, i_name, j_name, args, kwargs = _coconut_mock_func(skopt_backend.space, skopt_backend.model, i, j, *args, **kwargs)
+                _coconut_tre_check_0 = False
+            if _coconut_tre_check_0:
+                self, i_name, j_name, args, kwargs = _coconut_mock_6(skopt_backend.space, skopt_backend.model, i, j, *args, **kwargs)
                 continue
             else:
                 return partial_dependence(skopt_backend.space, skopt_backend.model, i, j, *args, **kwargs)
 
 
             return None
-    _coconut_recursive_func_25 = partial_dependence
+    _coconut_recursive_func_24 = partial_dependence
     def plot_partial_dependence_1D(self, i_name, ax=None, yscale=None, **kwargs):
         """Constructs a 1D partial dependence plot using self.partial_dependence."""
         xi, yi = self.partial_dependence(i_name, **kwargs)
@@ -547,3 +548,5 @@ class BlackBoxOptimizer(_coconut.object):
     def randn(self, name, *shape, **kwargs):
         """Create a new array parameter for the given name and shape modeled by np.random.randn."""
         return array_param(_coconut_partial(self.normalvariate, {1: 0, 2: 1}, 3), name, shape, kwargs)
+
+_coconut_call_set_names(BlackBoxOptimizer)
