@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# __coconut_hash__ = 0x398edda4
+# __coconut_hash__ = 0x3d99796
 
-# Compiled with Coconut version 1.5.0-post_dev12 [Fish License]
+# Compiled with Coconut version 1.5.0-post_dev49 [Fish License]
 
 # Coconut Header: -------------------------------------------------------------
 
@@ -14,7 +14,7 @@ if _coconut_cached_module is not None and _coconut_os_path.dirname(_coconut_cach
     del _coconut_sys.modules[str("__coconut__")]
 _coconut_sys.path.insert(0, _coconut_file_path)
 from __coconut__ import *
-from __coconut__ import _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
+from __coconut__ import _coconut_call_set_names, _coconut, _coconut_MatchError, _coconut_igetitem, _coconut_base_compose, _coconut_forward_compose, _coconut_back_compose, _coconut_forward_star_compose, _coconut_back_star_compose, _coconut_forward_dubstar_compose, _coconut_back_dubstar_compose, _coconut_pipe, _coconut_star_pipe, _coconut_dubstar_pipe, _coconut_back_pipe, _coconut_back_star_pipe, _coconut_back_dubstar_pipe, _coconut_none_pipe, _coconut_none_star_pipe, _coconut_none_dubstar_pipe, _coconut_bool_and, _coconut_bool_or, _coconut_none_coalesce, _coconut_minus, _coconut_map, _coconut_partial, _coconut_get_function_match_error, _coconut_base_pattern_func, _coconut_addpattern, _coconut_sentinel, _coconut_assert, _coconut_mark_as_match, _coconut_reiterable
 if _coconut_sys.version_info >= (3,):
     _coconut_sys.path.pop(0)
 
@@ -87,9 +87,28 @@ def get_nums(inputstr, numtype=float):
             pass
 
 
+def ave(xs):
+    return sum(xs) / len(xs)
+
+
+def assert_improving(data):
+    """Assert that the second half of data is greater/smaller than the first."""
+    examples = data["examples"]
+    half_pt = len(examples) // 2
+    first_half, second_half = examples[:half_pt], examples[half_pt:]
+    if "loss" in first_half[0]:
+        first_losses = (ave)((map)(_coconut.operator.itemgetter(("loss")), first_half))
+        second_losses = (ave)((map)(_coconut.operator.itemgetter(("loss")), second_half))
+        assert second_losses < first_losses, (first_losses, second_losses)
+    else:
+        first_gains = (ave)((map)(_coconut.operator.itemgetter(("gain")), first_half))
+        second_gains = (ave)((map)(_coconut.operator.itemgetter(("gain")), second_half))
+        assert second_gains > first_gains, (first_gains, second_gains)
+
+
 # Constants:
 
-NUM_TRIALS = 25
+NUM_TRIALS = 30
 
 example_dir = os.path.join(os.path.dirname(os.path.dirname(__file__)), "examples")
 
@@ -111,6 +130,9 @@ conditional_hyperopt_data = os.path.join(example_dir, "conditional_hyperopt_exam
 conditional_skopt_file = os.path.join(example_dir, "conditional_skopt_example.py")
 conditional_skopt_data = os.path.join(example_dir, "conditional_skopt_example.bbopt.pickle")
 
+bask_file = os.path.join(example_dir, "bask_example.py")
+bask_data = os.path.join(example_dir, "bask_example.bbopt.pickle")
+
 numpy_file = os.path.join(example_dir, "numpy_example.py")
 numpy_data = os.path.join(example_dir, "numpy_example.bbopt.pickle")
 
@@ -141,16 +163,43 @@ class TestExamples(unittest.TestCase):
     def test_skopt(self):
         print("\ntest skopt:")
         with using(skopt_data):
-            results = call_test(["bbopt", skopt_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", skopt_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = min(get_nums(results, numtype=float))
             assert os.path.exists(skopt_data)
 
             from bbopt.examples import skopt_example
-            skopt_example.bb.get_data(print_data=True)
+            assert_improving(skopt_example.bb.get_data(print_data=True))
             assert skopt_example.y == want
             assert -9 <= skopt_example.y < 21
             assert skopt_example.bb.num_examples == NUM_TRIALS
 
+    def test_conditional_skopt(self):
+        print("\ntest conditional_skopt:")
+        with using(conditional_skopt_data):
+            results = call_test(["bbopt", conditional_skopt_file, "-n", str(NUM_TRIALS), "-j", "2"])
+            want = max(get_nums(results, numtype=int))
+            assert os.path.exists(conditional_skopt_data)
+
+            from bbopt.examples import conditional_skopt_example
+            assert_improving(conditional_skopt_example.bb.get_data(print_data=True))
+            assert conditional_skopt_example.x == want
+            assert 0 < conditional_skopt_example.x <= 20
+            assert conditional_skopt_example.bb.num_examples == NUM_TRIALS
+
+    if sys.version_info >= (3, 7):
+        def test_bask(self):
+            print("\ntest bask:")
+            with using(bask_data):
+                results = call_test(["bbopt", bask_file, "-n", str(NUM_TRIALS), "-j", "2"])
+                want = max(get_nums(results, numtype=float))
+                assert os.path.exists(bask_data)
+
+                from bbopt.examples import bask_example
+                assert_improving(bask_example.bb.get_data(print_data=True))
+                assert 0 < want <= 20
+                assert 0 < bask_example.x <= 20
+                assert bask_example.bb.num_examples == NUM_TRIALS
+
     if sys.version_info >= (3,):
         def test_pysot(self):
             print("\ntest pysot:")
@@ -160,7 +209,7 @@ class TestExamples(unittest.TestCase):
                 assert os.path.exists(pysot_data)
 
                 from bbopt.examples import pysot_example
-                pysot_example.bb.get_data(print_data=True)
+                assert_improving(pysot_example.bb.get_data(print_data=True))
                 assert pysot_example.best_y == want
                 assert -9 <= pysot_example.best_y < 21
                 assert pysot_example.bb.num_examples == 20
@@ -168,52 +217,40 @@ class TestExamples(unittest.TestCase):
     def test_hyperopt(self):
         print("\ntest hyperopt:")
         with using(hyperopt_data):
-            results = call_test(["bbopt", hyperopt_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", hyperopt_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = min(get_nums(results, numtype=float))
             assert os.path.exists(hyperopt_data)
 
             from bbopt.examples import hyperopt_example
-            hyperopt_example.bb.get_data(print_data=True)
+            assert_improving(hyperopt_example.bb.get_data(print_data=True))
             assert hyperopt_example.y == want
             assert hyperopt_example.bb.num_examples == NUM_TRIALS
 
     def test_conditional_hyperopt(self):
         print("\ntest conditional_hyperopt:")
         with using(conditional_hyperopt_data):
-            results = call_test(["bbopt", conditional_hyperopt_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", conditional_hyperopt_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = max(get_nums(results, numtype=int))
             assert os.path.exists(conditional_hyperopt_data)
 
             from bbopt.examples import conditional_hyperopt_example
-            conditional_hyperopt_example.bb.get_data(print_data=True)
+            assert_improving(conditional_hyperopt_example.bb.get_data(print_data=True))
             assert conditional_hyperopt_example.x == want
             assert 0 < conditional_hyperopt_example.x <= 20
             assert conditional_hyperopt_example.bb.num_examples == NUM_TRIALS
 
-    def test_conditional_skopt(self):
-        print("\ntest conditional_skopt:")
-        with using(conditional_skopt_data):
-            results = call_test(["bbopt", conditional_skopt_file, "-n", str(NUM_TRIALS), "-j", "4"])
-            want = max(get_nums(results, numtype=int))
-            assert os.path.exists(conditional_skopt_data)
-
-            from bbopt.examples import conditional_skopt_example
-            conditional_skopt_example.bb.get_data(print_data=True)
-            assert conditional_skopt_example.x == want
-            assert 0 < conditional_skopt_example.x <= 20
-            assert conditional_skopt_example.bb.num_examples == NUM_TRIALS
-
     def test_numpy(self):
         print("\ntest numpy:")
         with using(numpy_data):
             from bbopt.examples import numpy_example
             assert numpy_example.y == 0
 
-            results = call_test(["bbopt", numpy_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", numpy_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = min(get_nums(results, numtype=float))
             assert os.path.exists(numpy_data)
 
             reload(numpy_example)
+            assert_improving(numpy_example.bb.get_data(print_data=True))
             assert numpy_example.y == want
             assert numpy_example.bb.num_examples == NUM_TRIALS
 
@@ -223,11 +260,12 @@ class TestExamples(unittest.TestCase):
             from bbopt.examples import mixture_example
             assert mixture_example.loss == abs(sum([3, 4, 5, 6, 7]) - 10)
 
-            results = call_test(["bbopt", mixture_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", mixture_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = min(get_nums(results, numtype=float))
             assert os.path.exists(mixture_data)
 
             reload(mixture_example)
+            assert_improving(mixture_example.bb.get_data(print_data=True))
             assert mixture_example.loss == want
             assert 0 <= mixture_example.loss < 85
             assert (len)((set)((map)(_coconut_base_compose(_coconut.operator.itemgetter(("memo")), (_coconut.operator.itemgetter(("alg")), 0)), mixture_example.bb.get_data()["examples"]))) > 1
@@ -239,14 +277,16 @@ class TestExamples(unittest.TestCase):
             from bbopt.examples import json_example
             assert round(json_example.y, 5) == 6
 
-            results = call_test(["bbopt", json_file, "-n", str(NUM_TRIALS), "-j", "4"])
+            results = call_test(["bbopt", json_file, "-n", str(NUM_TRIALS), "-j", "2"])
             want = min(get_nums(results, numtype=float))
             assert os.path.exists(json_data)
 
             reload(json_example)
+            assert_improving(json_example.bb.get_data(print_data=True))
             assert json_example.y == want
             assert json_example.bb.num_examples == NUM_TRIALS
 
 
+_coconut_call_set_names(TestExamples)
 if __name__ == "__main__":
     unittest.main()
